#
#  surfa01.py
#
#  Plot a 2D surface, level curves and profile projections on each plane.
#
#
import os                         # For issuing commands to the OS.
import sys                        # For determining the Python version.
#
# Call algebra and plot libraries
import matplotlib
from mpl_toolkits.mplot3d.axes3d import Axes3D
from matplotlib import rcParams
from pylab import *
import numpy as np
import matplotlib.pyplot as plt
#
rcParams['xtick.direction']  = 'out'
rcParams['ytick.direction']  = 'out'
rcParams['mathtext.fontset'] = 'cm'
rcParams['mathtext.rm']      = 'serif'
#
# Clear command shell
clear = lambda: os.system('clear')
clear()
#
# Print useful info
print 'Executing on', os.uname()
print 'Python version', sys.version
print 'matplotlib version', matplotlib.__version__
#
# Define parameters
Lx  = 10
Ly  = 10
nu  = 0.1
mu1 = 0.2
mu2 = 0.7
A   = 1.3
#
# Define 2D domain
X    = np.arange(-Lx, Lx, 0.02)
Y    = np.arange(-Ly, Ly, 0.02)
x, y = np.meshgrid(X, Y)
#
# Define curve-parameter on surface
t = np.arange(-Ly, Ly, 0.02)
#
# Set up a figure twice wider than its height
fig = plt.figure(figsize=plt.figaspect(0.5))
#
# Set up 3D axes
ax = fig.add_subplot(1, 1, 1, projection='3d')
#
# Define u = u(x,y)
rr = x**2+y**2
uu = A*np.exp(-nu*rr)*np.sin(mu1*x**2+mu2*y**2)
#
vv1 = A*np.exp(-nu*t**2)*np.sin(mu1*t**2)
vv2 = A*np.exp(-nu*t**2)*np.sin(mu2*t**2)
#
# Plot surface and level curves
ax.plot_wireframe(x,y, uu, rstride=20, cstride=20, alpha=0.1,color='grey')
ax.plot_surface(x,y, uu,rstride=10, cstride=10, alpha=0.7,cmap=cm.coolwarm)
cset = ax.contour(x,y, uu, 10, zdir='z', cmap=cm.coolwarm, offset=-0.1)
# Plot projection on ux plane and u = u(x,0)
cset = ax.contour(x,y, uu, 1, zdir='y', colors='b', offset=Ly+0.2)
ax.plot(t,Y*0,vv1,color='b',lw = 3)
# Plot projection on uy plane and u = u(0,y)
cset = ax.contour(x,y, uu, 1, zdir='x', colors='r', offset=Lx-0.2)
ax.plot(0*X,t,vv2,color='r',lw = 3)
# Set axes labels and title
ax.text(0, -15, -0.2, r'$x$',fontsize=30)
ax.text(-15, 0, -0.2, r'$y$',fontsize=30)
ax.text(-15, 10, 0.8, r'$z$',fontsize=30)
ax.set_zlim3d(-0.1,1)
ax.view_init(65, 225)
title(r'$f(x,y)=Ae^{-\nu (x^2+y^2)}\sin(\mu_1x^2+\mu_2y^2)$', fontsize=30)
#ax.view_init(90, 225)
#
# Get rid off panels
ax.w_xaxis.set_pane_color((1.0, 1.0, 1.0, 0.0))
ax.w_yaxis.set_pane_color((1.0, 1.0, 1.0, 0.0))
ax.w_zaxis.set_pane_color((1.0, 1.0, 1.0, 0.0))
#
# Get rid off ticks
ax.set_xticks([])
ax.set_yticks([])
ax.set_zticks([])
#
# Save figure on .png format
savefig('2Dsurf.png',dpi=300)
#---

show()



